//! @file DQtransform.cc
//! @brief dq変換行列 ＆ 逆dq変換行列
//!
//! dq変換行列
//!
//! @date 2019/02/24
//! @author Yusuke Asai & Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yusuke Asai & Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the FreeBSD License.
// For details, see the License.txt file.

#include <math.h>
#include "DQtransform.hh"

void ARCS::dq_uvw(double d, double q, double theta, double *u, double *v, double *w){
	// dq-uvw 変換行列 位置の単位に注意　degではなく『rad』
	*u=sqrt(2.0/3.0)*(d*cos(theta)-q*sin(theta));
	*v=sqrt(2.0/3.0)*(d*cos(theta-(2.0/3.0*M_PI))-q*sin(theta-(2.0/3.0*M_PI)));
	*w=-*u-*v;	
}

void ARCS::dq_uvw_inv(double u, double v, double w, double theta, double *d, double *q){
	// 逆行列
	*d=sqrt(2.0/3.0)*(u*cos(theta)+v*cos(theta-2.0/3.0*M_PI)+w*cos(theta+2.0/3.0*M_PI));
	*q=-sqrt(2.0/3.0)*(u*sin(theta)+v*sin(theta-2.0/3.0*M_PI)+w*sin(theta+2.0/3.0*M_PI));
}

void ARCS::dq_uv(double d, double q, double theta, double *u, double *v){
	// dq-uv 変換行列 位置の単位に注意　degではなく『rad』
	*u=sqrt(2.0/3.0)*(d*cos(theta)-q*sin(theta));
	*v=sqrt(2.0/3.0)*(d*cos(theta-(2.0/3.0*M_PI))-q*sin(theta-(2.0/3.0*M_PI)));
}

