//! @file Integrator.cc
//! @brief 積分器
//! @date 2017/06/09
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2017 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the FreeBSD License.
// For details, see the License.txt file.

#ifndef INTEGRATOR
#define INTEGRATOR

namespace ARCS {	// ARCS名前空間
	//! @brief 積分器
	class Integrator {
		public:
			//! @brief 積分方法の定義
			enum IntType {
				FOWARD_EULER,	//!< 前進オイラー(前進差分)
				BACKWARD_EULER,	//!< 後退オイラー(後退差分)
				TRAPEZOIDAL		//!< 台形積分(双1次変換, Tustin変換)
			};
			
			explicit Integrator(double SmplTime);			// コンストラクタ SmplTime；[s] 制御周期
			Integrator(double SmplTime, enum IntType Type);	// コンストラクタ(積分方法指定版) SmplTime；[s] 制御周期
			~Integrator();						// デストラクタ
			double GetSignal(double u);			// 出力信号の取得 u；入力信号
			void SetSmplTime(double SmplTime);	// 制御周期の再設定 SmplTime；[s] 制御周期
			void SetInitial(double InitValue);	// 積分初期値の設定 InitValue；初期値
			void Enable(bool Flag);				// 積分器を動かすか止めるか，Flag；trueのとき積分器作動，falseのとき積分停止
			void ClearStateVars(void);			// すべての状態変数のリセット
			
		private:
			Integrator(const Integrator&);					// コピーコンストラクタ使用禁止
			const Integrator& operator=(const Integrator&);	// 代入演算子使用禁止
			const IntType IntegType;	//!< 積分方法
			double Ts;	//!< [s]制御周期
			double uZ1;	//!< 状態変数1 変数名Z1の意味はz変換のz^(-1)を示す
			double yZ1;	//!< 状態変数2
			bool Ena;	//!< 積分器作動指令 trueのとき積分器作動，falseのとき積分停止
		
	};
}

#endif

