//! @file SFmultthread.hh
//! @brief 実時間マルチスレッド生成・破棄クラス(SCHED_FIFO版)
//! @date 2017/07/28
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2017 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the BSD License.
// For details, see the License.txt file.

#ifndef SFMULTTHRD
#define SFMULTTHRD

#include "SFthread.hh"

namespace ARCS {
	typedef void (**FuncPtrs)(void*);	// 関数ポインタ配列キャスト用
	
	//! @brief 実時間マルチスレッド生成・破棄クラス(SCHED_FIFO版)
	//!
	//! SCHED_FIFOリアルタイムマルチスレッドの生成と破棄をします。
	//!
	class SFmultthread {
		// 実時間マルチスレッド生成・破棄クラス
		public:
			// コンストラクタ
			SFmultthread(const unsigned int ThreadNum, void (** const PeriodicFuncs)(void*), void* const FuncArgs, const unsigned long* PeriodicTime, const unsigned int* CPUNumber);
			~SFmultthread();				// デストラクタ
			void Start(void);				// 実時間スレッドを開始させる関数
			void Stop(void);				// 実時間スレッドを終了させる関数
			void EmergencyStop(void);		// 実時間スレッドを緊急停止させる関数
			// 経過時間，測定した制御周期，計算に消費した時間，最大値，最小値を取得する関数(単位は秒) 
			void GetTimeValue(
				volatile double *Time,
				volatile double *PeriodicTime, 
				volatile double *ComputationTime, 
				volatile double *MaxTime, 
				volatile double *MinTime
			);
			
		private:
			SFmultthread(const SFmultthread&);						// コピーコンストラクタ使用禁止
			const SFmultthread& operator=(const SFmultthread&);		// 代入演算子使用禁止
			static const unsigned int MAX_THREAD = 128;	// スレッド最大数
			const unsigned int NumOfThread;				// 動作させるスレッドの数
			SFthread* pSFthread[MAX_THREAD];			// 実時間スレッド 0 ～ MAX_THREAD へのポインタ
	};
}

#endif

