//! @file Statistics.cc
//! @brief 統計処理
//! 平均，分散，標準偏差，共分散，相関係数の計算
//!
//! @date 2019/02/22
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the FreeBSD License.
// For details, see the License.txt file.

#ifndef STATISTICS
#define STATISTICS

namespace ARCS {
	double Average(const double *u, unsigned long N);						//!< 信号uの平均を計算する
	double Variance(const double *u, unsigned long N);						//!< 信号uの分散を求める
	double StandardDev(const double *u, unsigned long N);					//!< 信号uの標準偏差を求める
	double Covariance(const double *u1, const double *u2, unsigned long N);	//!< 信号u1と信号u2の間の共分散を計算する
	double Correlation(const double *u1, const double *u2, unsigned long N);//!< 信号u1と信号u2の間の相関係数を求める
}

#endif

