//! @file Interface.cc
//! @brief インターフェースクラス
//! @date 2019/04/01
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the BSD License.
// For details, see the License.txt file.

#include <new>
#include "Interface.hh"
#include "ARCSeventlog.hh"
#include "ARCSassert.hh"
#include "PCI-3340.hh"
#include "PCI-3343A.hh"
#include "PCI-3133.hh"
#include "PCI-3180.hh"
#include "PCI-6205C.hh"

using namespace ARCS;

// インターフェースボードクラスの定義と実体
namespace {
	// ここにD/A，A/D，エンコーダボードクラスの定義と実体を記述する
	PCI3340 DAC1;	// DACボード
	PCI3343A DAC2;	// DACボード
	PCI3133 ADC1;	// ADCボード
	PCI3180 ADC2;	// ADCボード
	PCI6205C ENC;	// ENCカウンタボード
}

//! @brief コンストラクタ
Interface::Interface(){
	PassedLog();
	// ここでD/A，A/D，エンコーダボードクラスを「placement new」で生成する
	// 下記のアドレスは lspci -vv で調べる。調べ方はWebを参照のこと。
	new(&DAC1) PCI3340(0x0000);	// DACボード
	new(&DAC2) PCI3343A(0x0000);// DACボード
	new(&ADC1) PCI3133(0x0000);	// ADCボード
	new(&ADC2) PCI3180(0x0000, PCI3180::RANGE_B_10V);			// ADCボード
	new(&ENC) PCI6205C(0x0000, 0x0000, 0x0000, 0x0000, 8, true);// ENCカウンタボード
	PassedLog();
}

//! @brief デストラクタ
Interface::~Interface(){
	SetZeroCurrent();	// 念のためのゼロ電流指令
	PassedLog();
	// (「placement new」の場合では delete は必要無し)
}

//! @brief サーボON信号を送出する関数
void Interface::ServoON(void){
	// ここにサーボアンプへのサーボON信号の送出シーケンスを記述する
	
}

//! @brief サーボOFF信号を送出する関数
void Interface::ServoOFF(void){
	// ここにサーボアンプへのサーボOFF信号の送出シーケンスを記述する
	
}

//! @brief 電流指令をゼロに設定する関数
void Interface::SetZeroCurrent(void){
	// ここにゼロ電流指令とサーボアンプの関係を列記する
	
}

//! @brief 位置応答を取得する関数
//! @param[out]	Position	位置応答
void Interface::GetPosition(std::array<double, ConstParams::ACTUATOR_MAX>& Position){
	// ここにエンコーダとPosition配列との関係を列記する
	
}

//! @brief トルク応答を取得する関数
//! @param[out]	Torque	トルク応答
void Interface::GetTorque(std::array<double, ConstParams::ACTUATOR_MAX>& Torque){
	// ここにトルクセンサとTorque配列との関係を列記する
	
}

//! @brief 電流応答を取得する関数
//! @param[out]	Current	電流応答
void Interface::GetCurrent(std::array<double, ConstParams::ACTUATOR_MAX>& Current){
	// ここに電流センサとCurrent配列との関係を列記する
	
}

//! @brief 電流指令を設定する関数
//! @param[in]	Current	電流指令
void Interface::SetCurrent(const std::array<double, ConstParams::ACTUATOR_MAX>& Current){
	// ここにCurrent配列とサーボアンプの関係を列記する
	
}

//! @brief Z相クリアに関する設定をする関数
void Interface::SetZpulseClear(const bool flag){
	// インクリメンタルエンコーダのZ(I,C)相クリアの設定が必要な場合に記述する
	
}

