//! @file ConstParams.cc
//! @brief 定数値格納用クラス
//!        ARCSに必要な定数値を格納します。
//! @date 2019/04/01
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the FreeBSD License.
// For details, see the License.txt file.

#include "ConstParams.hh"

// 注意！： const std::string は ConstParams.cc で定義すること。それ以外は constexpr として ConstParams.hh で定義。

using namespace ARCS;

// タイトルに表示させる制御系の名前(識別用に好きな名前を入力)
const std::string ConstParams::CTRLNAME("<TITLE: NO TITLE >");		//!< (画面に入る文字数以内)

// ARCS改訂番号(ARCSコード改変時にちゃんと変えること)
const std::string ConstParams::ARCS_REVISION("[REV.GNRL190401]");	//!< (16文字以内)

// イベントログの設定
const std::string ConstParams::EVENTLOG_NAME("./sys/EventLog.txt");	//!< イベントログファイル名

// 実験データファイルの設定
const std::string ConstParams::DATA_NAME("DATA.csv");				//!< ファイル名

// SCHED_FIFOリアルタイムスレッドの設定
constexpr unsigned long ConstParams::SAMPLING_TIME[THREAD_MAX];		//!< 制御周期の設定
constexpr unsigned int ConstParams::CPUCORE_NUMBER[THREAD_MAX];		//!< 使用CPUコアの設定

// 実験機アクチュエータの設定
constexpr ConstParams::ActType ConstParams::ACT_TYPE[ACTUATOR_MAX];	//!< 実験機アクチュエータの種類の設定（リニアモータか回転モータかの設定）
constexpr double ConstParams::ACT_FORCE_TORQUE_CONST[ACTUATOR_MAX];	//!< トルク/推力定数の設定
constexpr double ConstParams::ACT_RATED_CURRENT[ACTUATOR_MAX];		//!< 定格電流値の設定
constexpr double ConstParams::ACT_MAX_CURRENT[ACTUATOR_MAX];		//!< 瞬時最大許容電流値の設定
constexpr double ConstParams::ACT_GEAR_RATIO[ACTUATOR_MAX];			//!< 減速比の設定

// 任意変数値表示の設定
const std::string ConstParams::INDICVARS_FORMS[INDICVARS_MAX] = {
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
	"%13.4f",	// 任意に表示したい変数値の表示形式(printfの書式と同一)
};

// グラフプロットの共通設定
const std::string ConstParams::PLOT_FRAMEBUFF("/dev/fb0");		//!< フレームバッファ ファイルデスクリプタ
const std::string ConstParams::PLOT_TFORMAT("%1.1f");			//!< 横軸書式
const std::string ConstParams::PLOT_TLABEL("Time [s]");			//!< 横軸ラベル
constexpr std::array<bool, ConstParams::PLOT_MAX> ConstParams::PLOT_VISIBLE;			//!< グラフ描画の有効/無効設定
constexpr std::array<FrameGraphics::FGcolors, ConstParams::PLOT_VAR_MAX> ConstParams::PLOT_VAR_COLORS;	//!< 線の色
constexpr std::array<unsigned int, ConstParams::PLOT_MAX> ConstParams::PLOT_VAR_NUM;	//!< プロットする変数の数 (≦PLOT_VAR_MAX)
constexpr std::array<double, ConstParams::PLOT_MAX> ConstParams::PLOT_FMAX;				//!< 縦軸最大値
constexpr std::array<double, ConstParams::PLOT_MAX> ConstParams::PLOT_FMIN;				//!< 縦軸最小値
constexpr std::array<unsigned int, ConstParams::PLOT_MAX> ConstParams::PLOT_FGRID_NUM;	//!< 縦軸グリッドの分割数
constexpr std::array<int, ConstParams::PLOT_MAX> ConstParams::PLOT_LEFT;				//!< [px] 左位置
constexpr std::array<int, ConstParams::PLOT_MAX> ConstParams::PLOT_TOP;					//!< [px] 上位置
constexpr std::array<int, ConstParams::PLOT_MAX> ConstParams::PLOT_WIDTH;				//!< [px] 幅
constexpr std::array<int, ConstParams::PLOT_MAX> ConstParams::PLOT_HEIGHT;				//!< [px] 高さ

// グラフプロットの各部設定
//!< @brief 縦軸ラベルの設定
const std::array<std::string, ConstParams::PLOT_MAX> ConstParams::PLOT_FLABEL = {
	"---------- [-]",	// プロット0
	"---------- [-]",	// プロット1
	"---------- [-]",	// プロット2
	"---------- [-]",	// プロット3
	"---------- [-]",	// プロット4
	"---------- [-]",	// プロット5
	"---------- [-]",	// プロット6
	"---------- [-]",	// プロット7
	"---------- [-]",	// プロット8
	"---------- [-]",	// プロット9
	"---------- [-]",	// プロット10
	"---------- [-]",	// プロット11
	"---------- [-]",	// プロット12
	"---------- [-]",	// プロット13
	"---------- [-]",	// プロット14
	"---------- [-]",	// プロット15
};

//! @brief 縦軸書式
const std::array<std::string, ConstParams::PLOT_MAX> ConstParams::PLOT_FFORMAT = {
	"%1.1f",	// プロット0
	"%1.1f",	// プロット1
	"%1.1f",	// プロット2
	"%1.1f",	// プロット3
	"%1.1f",	// プロット4
	"%1.1f",	// プロット5
	"%1.1f",	// プロット6
	"%1.1f",	// プロット7
	"%1.1f",	// プロット8
	"%1.1f",	// プロット9
	"%1.1f",	// プロット10
	"%1.1f",	// プロット11
	"%1.1f",	// プロット12
	"%1.1f",	// プロット13
	"%1.1f",	// プロット14
	"%1.1f",	// プロット15
};

//! @brief 変数の名前
const std::array<
	std::array<std::string, ConstParams::PLOT_VAR_MAX>,
ConstParams::PLOT_MAX> ConstParams::PLOT_VAR_NAMES = {{
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット0
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット1
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット2
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット3
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット4
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット5
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット6
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット7
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット8
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット9
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット10
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット11
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット12
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット13
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット14
	{"VAR-01", "VAR-02", "VAR-03", "VAR-04", "VAR-05", "VAR-06", "VAR-07", "VAR-08",},	// プロット15
}};


