//! @file Interface.hh
//! @brief インターフェースクラス
//! @date 2019/02/24
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the BSD License.
// For details, see the License.txt file.

#ifndef ARCS_INTERFACE
#define ARCS_INTERFACE

#include <array>
#include "ConstParams.hh"

// 前方宣言
namespace ARCS {
	
}

namespace ARCS {	// ARCS名前空間
	//! @brief インターフェースクラス
	//! 「電流指令,位置,トルク,…等々」と「DAC,エンコーダカウンタ,ADC,…等々」との対応を指定します。
	class Interface {
		public:
			Interface();	//!< コンストラクタ
			~Interface();	//!< デストラクタ
			static void ServoON(void);			//!< サーボON信号を送出する関数
			static void ServoOFF(void);			//!< サーボOFF信号を送出する関数
			static void SetZeroCurrent(void);	//!< 電流指令をゼロに設定する関数
			static void GetPosition(std::array<double, ConstParams::ACTUATOR_MAX>& Position);		//!< 位置応答を取得する関数
			static void GetTorque(std::array<double, ConstParams::ACTUATOR_MAX>& Torque);			//!< トルク応答を取得する関数
			static void GetCurrent(std::array<double, ConstParams::ACTUATOR_MAX>& Current);			//!< 電流応答を設定する関数
			static void SetCurrent(const std::array<double, ConstParams::ACTUATOR_MAX>& Current);	//!< 電流指令を設定する関数
			static void SetZpulseClear(const bool flag);	//!< Z相クリア設定
		
		private:
			Interface(const Interface&) = delete;					//!< コピーコンストラクタ使用禁止
			const Interface& operator=(const Interface&) = delete;	//!< 代入演算子使用禁止
	};
}

#endif

