//! @file ARCSeventlog.hh
//! @brief ARCS イベントログクラス
//!
//! ARCS用のイベントログクラス
//! 注意：リアルタイム空間ではこのライブラリが提供する関数は可能な限り使用しないこと。ジッタに影響するので。デバッグ時なら使用OK。
//!
//! @date 2019/01/25
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the FreeBSD License.
// For details, see the License.txt file.

#ifndef ARCSEVENTLOG
#define ARCSEVENTLOG

#include <string>

// 関数呼び出し用マクロ
#define PassedLog() (ARCSeventlog::PassedLog_from_macro(__FILE__,__LINE__))				//!< イベントログ用マクロ（ファイルと行番号のみ記録版）
#define EventLog(a) (ARCSeventlog::EventLog_from_macro(a,__FILE__,__LINE__))			//!< イベントログ用マクロ (任意メッセージ記録版)
#define EventLogVar(a) (ARCSeventlog::EventLogVar_from_macro(a,#a,__FILE__,__LINE__))	//!< 変数用イベントログマクロ  a : 表示する変数

// 前方宣言
namespace ARCS {
	class ARCSscreen;
}

namespace ARCS {
	//! @brief ARCS イベントログクラス(静的クラス)
	class ARCSeventlog {
		public:
			// イベントログ設定用関数
			static void Init(void);							//!< イベントログを初期化する関数
			static void SetScreenPtr(ARCSscreen* ScrPtr);	//!< ARCS画面ポインタの設定
			
			// 下記の関数はマクロから呼ばれることを想定
			static void EventLog_from_macro(const std::string& str, const std::string& file, const int line);	//!< イベントログを残す関数 (任意メッセージ記録版)
			static void EventLogVar_from_macro(const double u, const std::string& varname, const std::string& file, const int line);	//!< 変数用イベントログ  u : 表示する変数, varname : 変数名
			static void PassedLog_from_macro(const std::string& file, const int line);							//!< イベントログを残す関数（ファイルと行番号のみ記録版）
			
			static void WriteEventLog(const std::string& str, const std::string& file, const int line);	//!< イベントログをファイルに書き出す
			
		private:
			ARCSeventlog() = delete;					//!< コンストラクタ使用禁止
			~ARCSeventlog() = delete;					//!< デストラクタ使用禁止
			ARCSeventlog(const ARCSeventlog&) = delete;	//!< コピーコンストラクタ使用禁止
			const ARCSeventlog& operator=(const ARCSeventlog&) = delete;	//!< 代入演算子使用禁止
			
			static ARCSscreen* ARCSscreenPtr;			//!< ARCS画面ポインタ
	};
}

#endif

