//! @file ARCSthread.hh
//! @brief ARCSリアルタイムスレッド管理クラス
//!
//! リアルタイムスレッドの生成、開始、停止、破棄などの管理をします。
//!
//! @date 2019/01/20
//! @author Yuki YOKOKURA
//
// Copyright (C) 2011-2019 Yuki YOKOKURA
// This program is free software;
// you can redistribute it and/or modify it under the terms of the FreeBSD License.
// For details, see the License.txt file.

#ifndef ARCSTHREAD
#define ARCSTHREAD

#include <pthread.h>

// 前方宣言
namespace ARCS {
	class ControlFunctions;
	class SFmultthread;
}

namespace ARCS {	// ARCS名前空間
	//! @brief ARCSリアルタイムスレッド管理クラス
	class ARCSthread {
		public:
			ARCSthread();				//!< コンストラクタ
			~ARCSthread();				//!< デストラクタ
			void Start(void);			//!< スレッドを開始する関数
			void Stop(void);			//!< スレッドを停止する関数
			void Reset(void);			//!< スレッドをリセットする関数
			void SaveDataFiles(void);	//!< 測定データを保存する関数
			
		private:
			ARCSthread(const ARCSthread&) = delete;					//!< コピーコンストラクタ使用禁止
			const ARCSthread& operator=(const ARCSthread&) = delete;//!< 代入演算子使用禁止
			ControlFunctions* CtrlFuncs;				//!< 制御用周期実行関数群
			SFmultthread* RealtimeThreads;				//!< リアルタイムマルチスレッド
			pthread_t InfoGetThreadID;					//!< 情報取得スレッドの識別子
			static void InfoGetThread(ARCSthread* const p);	//!< 情報取得スレッド
	};
}

#endif

